@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -38,7 +38,7 @@ def run():
     reset()
 
     basechoices = ['Triangles', 'Quadrilaterals']
-    renderchoices = renderModes()
+    renderchoices = pf.canvas.renderModes()
     res = askItems([
         _I('baseGeom', itemtype='radio', choices=basechoices, text='Type of surface element'),
         _I('nbumps', 3, text='Number of bumps'),
