@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -27,8 +27,6 @@
 """Menu with pyFormex apps.
 
 """
-import random
-
 import pyformex as pf
 from pyformex import Path
 from pyformex import apps
@@ -80,15 +78,15 @@ def classify(appdir, pkg, nmax=0):
 
     for i, appname in enumerate(all_apps):
 
-        #col['all'].update([appname])
+        # col['all'].update([appname])
         try:
             fullname = str(pkg)+'.'+appname
             app = apps.load(fullname, strict=True)
             if app is None:
-                raise RuntimeError("App '%s' has no run method" % fullname)
+                raise RuntimeError(f"App '{fullname}' has no run method")
         except Exception:
             app = failed
-            print("Failed to load app '%s'" % fullname)
+            print("Failed to load app", fullname)
 
         for k in kat:
             if hasattr(app, '_'+k):
@@ -201,7 +199,7 @@ class AppMenu(menu.Menu):
 
     Apps are simply Python modules that have a 'run' function.
     Only these modules will be added to the menu.
-    Only files that are recognized by :func:`utils.is_pyFormex()` as being
+    Only files that are recognized by :func:`utils.is_script()` as being
     pyFormex scripts will be added to the menu.
 
     The constructor takes the following arguments:
@@ -212,7 +210,7 @@ class AppMenu(menu.Menu):
       '.' or '_', will be considered for inclusion in the menu.
       If mode=='app', they will only be included if
       they can be loaded as a module. If mode=='script', they will only be
-      included if they are considered a pyFormex script by utils.is_pyFormex.
+      included if they are considered a pyFormex script by utils.is_script.
       If `files` is specified, `dir` will just be prepended to each file in
       the list.
     - `files`: an explicit list of file names of pyFormex scripts.
@@ -275,10 +273,10 @@ class AppMenu(menu.Menu):
 
     def __init__(self, title, dir=None, files=None, mode='app', ext=None,
                  recursive=None, max=0, autoplay=False, toplevel=True,
-                 parent=None, before=None):
+                 parent=None, before=None, maxsize=0):
         """Create a menu with pyFormex apps/scripts to play."""
-        pf.debug("New AppMenu %s: dir=%s; files=%s" % (title, dir, files),
-                 pf.DEBUG.APPS)
+        if pf.debugon(pf.DEBUG.APPS):
+            print(f"New AppMenu {title}: {dir=}; {files=}")
         menu.Menu.__init__(self, title, parent=parent, before=before)
         if dir is None and files is None:
             raise ValueError("At least one of 'dir' or 'files' must be set.")
@@ -305,13 +303,22 @@ class AppMenu(menu.Menu):
         else:
             self.pkg = None
         self.load()
+        # if maxsize > 0:
+        #     self.split(maxsize)
 
 
     def loadCatalog(self):
         catfile = self.dir / catname
+        if pf.debugon(pf.DEBUG.APPS):
+            print(f"Loading {catfile=}: {catfile.exists()}")
+        mylocals = {}
         if catfile.exists():
-            utils.execFile(str(catfile), globals())
+            # This overrides the variables defined above
+            utils.execFile(catfile, globals(), mylocals)
+            kat, cat, col = (mylocals.pop(i) for i in ('kat', 'cat', 'col'))
             for k in kat:
+                if pf.debugon(pf.DEBUG.APPS):
+                    print(f"Creating submenu {k}")
                 if k == 'all_apps' and self.mode != 'app':
                     files = col[k]
                 else:
@@ -327,10 +334,10 @@ class AppMenu(menu.Menu):
                         # string from catalog file
                         lbl = i.capitalize()
                     ki = '%s/%s' % (k, i)
-                    mi = AppMenu(lbl, dir=self.dir, files=col.get(ki, []),
-                                 mode=self.mode, recursive=False,
-                                 toplevel=False, autoplay=self.autoplay,
-                                 parent=mk)
+                    _ = AppMenu(lbl, dir=self.dir, files=col.get(ki, []),
+                                mode=self.mode, recursive=False,
+                                toplevel=False, autoplay=self.autoplay,
+                                parent=mk)
             self.files = []
             return True
         return False
@@ -341,31 +348,26 @@ class AppMenu(menu.Menu):
             dirs = self.dir.dirnames()
         for d in dirs:
             if d[0] not in '._':  # skip hidden and private dirs
-                m = AppMenu(d, self.dir / d, mode=self.mode, ext=self.ext,
+                _ = AppMenu(d, self.dir / d, mode=self.mode, ext=self.ext,
                             autoplay=self.autoplay, recursive=self.recursive,
-                            parent=self)
+                            parent=self, maxsize=pf.cfg['gui/scripts_max'])
 
 
     def getFiles(self):
         """Get a list of scripts in self.dir"""
         files = [f for f in self.dir.filenames() if f[0] not in '._']
         if self.ext:
-            filtr = lambda s: s.endswith(self.ext)
             n = len(self.ext)
-            files = [f[:-n] for f in files if filtr(f)]
-
+            files = [f[:-n] for f in files if f.endswith(self.ext)]
         files = sorted(self.filterFiles(files))
         return files
 
 
     def filterFiles(self, files):
         """Filter a list of scripts"""
-        filtr = lambda s: utils.is_pyFormex(self.fileName(s))
-        files = [f for f in files if filtr(f)]
-
+        files = [f for f in files if utils.is_script(self.fileName(f))]
         if self.max > 0 and len(files) > self.max:
             files = files[:self.max]
-
         return files
 
 
@@ -385,7 +387,9 @@ class AppMenu(menu.Menu):
 
         self.files = files
 
-        pf.debug("Found %ss in %s\n%s" % (self.mode.capitalize(), self.dir, self.files), pf.DEBUG.APPS)
+        if pf.debugon(pf.DEBUG.APPS):
+            print(f"Found {self.mode.capitalize()}s in {self.dir}:")
+            print(self.files)
 
         self.my_actions = [self.insert_action(str(f)) for f in self.files]
         self.triggered.connect(self.run)
@@ -442,7 +446,7 @@ class AppMenu(menu.Menu):
 
         This is only for app mode menus!
         """
-        files = [ self.fullAppName(f) for f in self.files]
+        files = [self.fullAppName(f) for f in self.files]
         if recursive:
             for name in self.menuNames():
                 files.extend(self[name].listApps(recursive=True))
@@ -466,14 +470,15 @@ class AppMenu(menu.Menu):
         and run it if play==True.
         """
         self.current = app
-        #if self.mode != 'app':
+        # if self.mode != 'app':
         pf.GUI.setcurfile(app)
         if play:
             if self.mode == 'app':
                 appname = self.fullAppName(app)
             else:
                 appname = self.fileName(app)
-            pf.debug("Running application %s" % appname, pf.DEBUG.APPS|pf.DEBUG.MENU)
+            if pf.debugon(pf.DEBUG.APPS | pf.DEBUG.MENU):
+                print(f"Running application {appname}")
             script.runAny(appname)
 
 
@@ -514,7 +519,7 @@ class AppMenu(menu.Menu):
 
         if tcount > 0:
             # Run these files
-            print("Running %s applications from '%s'" % (len(files), self.title()))
+            print(f"Running {len(files)} applications from '{self.title()}'")
             print(files)
             pf.GUI.runallmode = True
             save = widgets.input_timeout
@@ -526,7 +531,7 @@ class AppMenu(menu.Menu):
                     layout(1)
                     reset()
                     pf.PF.clear()
-                    print("Running app '%s'" % f)
+                    print("Running app", f)
                     self.runApp(f)
                     script.breakpt(msg="Breakpoint from runall")
                     if script.exitrequested:
@@ -543,13 +548,13 @@ class AppMenu(menu.Menu):
         if recursive and (count < 0 or tcount < count):
             for name in self.menuNames:
                 n = self[name].runAll(startfrom, stopat, count=count-tcount,
-                             recursive=recursive, random=random)
+                                      recursive=recursive, random=random)
                 tcount += n
                 if count > 0 and tcount >= count:
-                    print("Ran %s examples; getting out" % tcount)
+                    print(f"Ran {tcount} examples; getting out")
                     break
                 else:
-                    print("Still want %s more examples" % (count-tcount))
+                    print(f"Still want {count-tcount} more examples")
 
         pf.GUI.enableButtons(pf.GUI.actions, ['Stop'], False)
         return tcount
@@ -562,7 +567,8 @@ class AppMenu(menu.Menu):
         This is only available if a directory path was specified and
         no files.
         """
-        pf.debug("Reloading this menu", pf.DEBUG.APPS)
+        if pf.debugon(pf.DEBUG.APPS):
+            print("Reloading this menu")
         if self.dir:
             self.clear()
             self.files = None
@@ -585,7 +591,7 @@ class AppMenu(menu.Menu):
                     print("%s is not a pyFormex app!" % appname)
                     return
             else:
-                if not utils.is_pyFormex(name):
+                if not utils.is_script(name):
                     return
                 if skipconfig:
                     # This is here to skip the startup script
@@ -604,7 +610,8 @@ class AppMenu(menu.Menu):
 
     def _classify(self, nmax=20):
         """Classify, symlink and reload the scripts"""
-        pf.debug("Classifying scripts", pf.DEBUG.APPS)
+        if pf.debugon(pf.DEBUG.APPS):
+            print("Classifying scripts")
         if self.dir:
             fn = self.dir / catname
             all_apps, kat, cat, col = classify(self.dir, self.pkg, nmax)
@@ -642,7 +649,7 @@ def unloadCurrentApp():
     apps.unload(appname)
 
 
-def createAppMenu(mode='app', parent=None, before=None):
+def createAppMenu(mode='app', parent=None, before=None, maxsize=0):
     """Create the menu(s) with pyFormex apps
 
     This creates a menu with all examples distributed with pyFormex.
@@ -658,23 +665,26 @@ def createAppMenu(mode='app', parent=None, before=None):
     replaced.
     """
     Mode = mode.capitalize()
-    appmenu = menu.Menu('&%s'%Mode, parent=parent, before=before)
+    appmenu = menu.Menu('&'+Mode, parent=parent, before=before)
     appmenu.mode = mode
     if mode == 'app':
         appdirs = [(d.name, d.path) for d in pf.appdirs]
     else:
         appdirs = pf.cfg['scriptdirs']
 
-
-    history = AppMenu('History', files=pf.cfg['gui/%shistory'%mode], max=pf.cfg['gui/history_max'], mode=mode, parent=appmenu)
+    history = AppMenu('History', files=pf.cfg[f'gui/{mode}history'],
+                      max=pf.cfg['gui/history_max'], mode=mode, parent=appmenu)
 
     # Fill in missing default locations : this enables the user
     # to keep the pyFormex installed examples in his config
     appdirs = [(d[0], apps.guessDir(*d)) for d in appdirs]
     appdirs = [d for d in appdirs if d[1].exists() and d[1].is_dir()]
     for name, path in appdirs:
-        pf.debug("Loading menu %s from %s" % (name, path), pf.DEBUG.MENU)
-        m = AppMenu(name, path, mode=mode, autoplay=True, parent=appmenu)
+        if pf.debugon(pf.DEBUG.APPS | pf.DEBUG.MENU):
+            print("Loading menu %s from %s" % (name, path))
+        _m = AppMenu(name, path, mode=mode, autoplay=True, parent=appmenu,
+                     maxsize=pf.cfg['gui/scripts_max'])
+        _m.split(pf.cfg['gui/scripts_max'])
 
     setattr(pf.GUI, f"{mode}history", history)
 
@@ -683,17 +693,16 @@ def createAppMenu(mode='app', parent=None, before=None):
         (f'Show {Mode} Info', draw.showDoc),
         (f'Configure {Mode} Paths', Settings.setDirs, {'data': f'{mode}dirs'}),
         (f'Reload {Mode} Menu', reloadMenu, {'data': mode}),
-        ])
+    ])
     if mode == 'app':
         appmenu.insertItems([
             ('List loaded Apps', script.printLoadedApps),
             ('Unload Current App', unloadCurrentApp),
-            ])
+        ])
     if mode == 'script':
         appmenu.insertItems([
             ('Force Finish Script', script.force_finish),
         ])
-
     return appmenu
 
 
@@ -704,7 +713,8 @@ def reloadMenu(mode='app'):
     item = pf.GUI.menu.action(name)
     if item is not None:
         before = pf.GUI.menu.nextItem(item)
-        print("ITEM BEFORE ",before)
+        if pf.debugon(pf.DEBUG.MENU):
+            print("ITEM BEFORE ", before)
         pf.GUI.menu.removeItem(item)
         if mode == 'app':
             # reset pf.appdirs, we may have configuration changes
