@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -31,12 +31,11 @@ pyFormex GUI function. Most of these dialogs are normally accessed from
 the GUI menus. But the user can also use these in his scripts.
 """
 import pyformex as pf
-from pyformex import utils
 from pyformex.path import Path
 from pyformex.script import chdir
-from pyformex.gui.widgets import Dialog, _I, _C, _G, _T, InputBool
-from pyformex.gui import image
-from pyformex.gui import qtutils
+
+from . import image
+from .widgets import Dialog, _I, _C, InputBool
 
 
 def addToSidebar(path):
@@ -63,6 +62,18 @@ class FileDialog(Dialog):
         The initial path displayed in the file selector widget.
     filter: list of str
         The filters for the files selectable in the file selector widget.
+    path: :term:`path_like`
+        The initial path displayed in the selector widget. It can be a
+        directory or a file. All the files in the provided directory (or the
+        file's parent) that match the ``filter`` will be initially presented
+        to the user.
+    filter: str or list of str
+        Specifies a (set of) filter(s) to be applied on the files in the
+        selection directory. Only the selectable files will be presented in
+        the selector widget. The ``filter`` argument is passed
+        through the :func:`utils.fileDescription` function to create the
+        actual filter set. If multiple filters are included, the user can
+        switch between them in the dialog.
     mode: str
         Determines what can be selected. One of:
 
@@ -84,12 +95,23 @@ class FileDialog(Dialog):
         A list of :term:`path_like` strings to add to the sidebar of the
         file selection widget. This is typically used to provide shortcuts
         to often used directories.
+    add_to_sidebar: bool
+        If True (default), an extra check option is added to the FileDialog,
+        and if the user checks the option, the selected item directory will be
+        added to the sidebar in future FileDialogs.
+        If False, this option is not presented.
+    chdir: bool
+        If True (default), an extra check option is added to the FileDialog,
+        and if the user checks the option, the selected item directory will be
+        made the current working directory.
+        If False, this option is not presented.
     extra: list
-        A list of input items to be added to the FileDialog. No input item
-        should be named 'filename'.
-    kargs:
-        Other keyword parameters to be passed to the :class:`Dialog` super
-        class.
+        A list with extra input items to be added to the FileDialog. No input
+        item should be named 'filename'.
+    **kargs:
+        Other keyword parameters are passed to the :class:`Dialog` constructor.
+        Some of them have another default value: ``modal=False``,
+        ``caption='"pyFormex File Dialog'``, ``parent=pf.GUI``.
 
     Returns
     -------
@@ -112,41 +134,41 @@ class FileDialog(Dialog):
         'dir': 'Select a directory',
         'any': 'Select a file or a directory',
         'multi': 'Select multiple existing paths from one directory',
-        }
+    }
 
     def __init__(self, path='.', filter='*', *, mode='file',
                  compr=False, auto_suffix=True,
                  sidebar=[], add_to_sidebar=False, chdir=False,
-                 extra=[], enablers=[],
-                 caption="pyFormex File Dialog",
+                 extra=[], enablers=[], modal=False,
+                 caption="pyFormex File Dialog", parent=pf.GUI,
                  **kargs):
         """Create the dialog."""
-        pf.verbose(3, f"FILEDIALOG mode {mode} kargs {kargs}")
+        if pf.verbosity(3):
+            print(f"FILEDIALOG mode {mode} kargs {kargs}")
         items=[
             _I('filename', path, itemtype='file', filter=filter, mode=mode,
                compr=compr, auto_suffix=auto_suffix, sidebar=sidebar, text=''),
-            ] + extra
+        ] + extra
         # TODO: if we want to make the auto_suffix a dialog item,
         # we have to connect the changing of the auto_suffix value to an
         # auto_suffix setter on the filename item.
-
-        super().__init__(items=items, enablers=enablers, modal=False,
-                         caption=caption, parent=pf.GUI,
-                         message=FileDialog.message[mode])
+        super().__init__(items=items, enablers=enablers, modal=modal,
+                         caption=caption, parent=parent,
+                         message=FileDialog.message[mode], **kargs)
 
         layout = self['filename'].input.layout()
         if add_to_sidebar is not None:
             self.sidebar = InputBool(
                 '_sidebar', add_to_sidebar, text='Add to sidebar')
-            layout.addWidget(self.sidebar,2,2)
+            layout.addWidget(self.sidebar, 2, 2)
         if chdir is not None:
             self.chdir = InputBool(
                 '_chdir', chdir, text='Change workdir')
-            layout.addWidget(self.chdir,3,2)
+            layout.addWidget(self.chdir, 3, 2)
             self.mode = mode
 
 
-    def selectFile(self,fn):
+    def selectFile(self, fn):
         """Set the current selection on the file widget"""
         self['filename'].input.selectFile(fn)
 
@@ -154,9 +176,9 @@ class FileDialog(Dialog):
     def close(self):
         """Perform additional actions on close"""
         if self.results:
-            if hasattr(self,'sidebar') and self.sidebar.value():
+            if hasattr(self, 'sidebar') and self.sidebar.value():
                 addToSidebar(self.results['filename'])
-            if hasattr(self,'chdir') and self.chdir.value():
+            if hasattr(self, 'chdir') and self.chdir.value():
                 dirname = self.results['filename']
                 if self.mode == 'multi':
                     dirname = dirname[0]
@@ -177,9 +199,9 @@ class GeometryFileDialog(FileDialog):
         """Create the dialog."""
         print(f"KARGS1 {kargs}")
         kargs.setdefault('caption', "pyFormex Geometry File Dialog")
+        kargs.setdefault('exist', False)
         # TODO: should set mode based on access and exist
         kargs['mode'] = 'file'
-        exist = kargs.setdefault('exist', False)
         if intend == 'r':
             access = ['r']
         elif intend == 'w':
@@ -190,7 +212,7 @@ class GeometryFileDialog(FileDialog):
             _I('access', itemtype='radio', text="Access Mode", choices=access,
                spacer='r',
                tooltip="wr=read if exist; rw=must exist; w=overwrite; r=readonly"
-            )]
+               )]
         if 'w' in access:
             extra.extend([
                 _I('mode', fmode, itemtype='radio', text="Write mode",
@@ -198,13 +220,13 @@ class GeometryFileDialog(FileDialog):
                    tooltip="'binary' produces smaller files, "
                    "'short lines ascii' is easier to edit, "
                    "'ascii' types may be compressed to produce smaller files",
-                ),
+                   ),
                 _I('compression', compression, itemtype='slider',
                    min=0, max=9, ticks=1,
                    text="Compression level (0-9)",
                    tooltip="Higher compression levels result in smaller "
                    "files, but higher load and save times."
-                )
+                   )
             ])
         print(f"KARGS2 {kargs}")
         super().__init__(path, filter='pgf', extra=extra, **kargs)
@@ -228,7 +250,7 @@ class ProjectDialog(FileDialog):
             _I('access', itemtype='radio', text="Access Mode", choices=access,
                spacer='r',
                tooltip="wr=read if exist; rw=must exist; w=overwrite; r=readonly"
-            ),
+               ),
         ]
         if exist:
             extra.append(
@@ -240,7 +262,7 @@ class ProjectDialog(FileDialog):
                    "is if you still need to read your files with older "
                    "versions of pyFormex. The conversion will not be "
                    "performed if pyFormex can not correctly read your file.",
-                ))
+                   ))
         if not exist:
             if protocol is None:
                 protocol = project.default_protocol
@@ -248,15 +270,15 @@ class ProjectDialog(FileDialog):
                 _I('protocol', protocol, itemtype='int',
                    text="Protocol",
                    min=0, max=pickle.HIGHEST_PROTOCOL, ticks=1,
-                   tooltip = "Use at most protocol 2 if you need to read "
+                   tooltip="Use at most protocol 2 if you need to read "
                    "back the project from Python2 version"
-                ),
+                   ),
                 _I('compression', compression, itemtype='slider',
                    min=0, max=9, ticks=1,
                    text="Compression level (0-9)",
                    tooltip="Higher compression levels result in smaller "
                    "files, but higher load and save times."
-                )
+                   )
             ])
         super().__init__(path, filter='pyf', extra=extra, **kargs)
 
@@ -295,7 +317,7 @@ class SaveImageDialog(FileDialog):
         kargs['caption'] = "pyFormex Save Image Dialog"
         kargs['exist'] = False
         extra=[
-            _C('',[
+            _C('', [
                 _I('extent', choices=image.image_extents(),
                    text="Extent:",
                    func=self.change_extent,
@@ -305,7 +327,7 @@ class SaveImageDialog(FileDialog):
                    # func=self.change_tool,  # can not do both !!
                    tooltip="The tool to be used for saving the image."
                    " The possible extents and formats depend on it."),
-               _I('set_size', choices=['No', 'Width', 'Height', 'Both'],
+                _I('set_size', choices=['No', 'Width', 'Height', 'Both'],
                    text='Set Size:',
                    tooltip="Adjust one or both image dimensions. Beware, "
                    " this may give incorrect results if transparency is used."),
@@ -315,7 +337,7 @@ class SaveImageDialog(FileDialog):
                    text="Size:",
                    tooltip="The size of the save image."),
             ], newline=True),
-            _C('',[
+            _C('', [
                 _I('format', choices=['From Extension'],
                    text="Format:",
                    tooltip="The image format to be used. Normally derived from"
@@ -327,7 +349,7 @@ class SaveImageDialog(FileDialog):
                 _I('alpha', False, text="Keep Alpha",
                    tooltip="Keep the alpha channel in the result (Experimental!)"),
             ], spacer='l'),
-            _C('',[
+            _C('', [
                 _I('multi', False,
                    text="Multisave mode",
                    tooltip="In multisave mode you can save sequences of images,"
@@ -410,12 +432,12 @@ class RecordSessionDialog(FileDialog):
     def __init__(self, path=None, filter=['video', 'all']):
         """Create the dialog."""
         extra = [
-            _C('',[
+            _C('', [
                 _I('extent', choices=image.record_extents,
                    text="Extent:",
                    tooltip="The part(s) of the pyFormex window to be saved"),
             ]),
-            _C('',[
+            _C('', [
                 _I('framerate', 25,
                    text="framerate:",
                    tooltip="The number of frames saved per second."),
@@ -423,4 +445,4 @@ class RecordSessionDialog(FileDialog):
         ]
 
         super().__init__(path, filter, extra=extra,
-                       caption="pyFormex Record Session Dialog")
+                         caption="pyFormex Record Session Dialog")
