@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -33,23 +33,12 @@ import sys
 import os
 import importlib
 import datetime
-import types
-import warnings
 
 import pyformex as pf
 from pyformex import Path
 from pyformex import process
 from pyformex import utils
-from pyformex import software
-
-# If we get here, either PySide2 or PyQt5 are imported
-# Check for OpenGL
-if not pf.sphinx:
-    if pf.options.mgl:
-        software.Module.has('moderngl', fatal=True)
-    elif not pf.options.gl3:
-        software.Module.has('pyopengl', fatal=True)
-software.Module.has('pil', fatal=True)
+from pyformex import core
 
 from pyformex.gui import (QtCore, QtGui, QtWidgets, QPixmap)
 from pyformex.gui import signals
@@ -165,7 +154,7 @@ class FileWatcher(QtCore.QFileSystemWatcher):
         path: :term:`path_like`
             The path of the file to be watched.
         """
-        if path in self.fileWatched:
+        if path in self.filesWatched:
             self.removePath(path)
             del self.filesWatched[path]
 
@@ -174,7 +163,8 @@ class FileWatcher(QtCore.QFileSystemWatcher):
         print(f"FileWatcher: file {path} has changed")
         f = self.filesWatched.get(path, None)
         if f:
-            pf.verbose(2, f"FileWatcher: calling {f.__name__}({path})")
+            if pf.verbosity(2):
+                print(f"FileWatcher: calling {f.__name__}({path})")
             f(path)
 
 
@@ -204,10 +194,11 @@ class Gui(QtWidgets.QMainWindow):
                     }
 
 
-    def __init__(self, windowname, size=(800, 600), pos=(0, 0),
+    def __init__(self, windowname, size=(800, 600), pos=(0, 0),  # noqa: C901
                  splitsize=(450, 150)):
         """Constructs the GUI."""
-        pf.debug(f'Creating Main Window with size {size} at {pos}', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print(f'Creating Main Window with size {size} at {pos}')
         super().__init__()
         self.setWindowTitle(windowname)
         self.on_exit = set()    # exit functions
@@ -216,7 +207,8 @@ class Gui(QtWidgets.QMainWindow):
         size = qtutils.MinSize(size, self.maxsize)
 
         # The status bar
-        pf.debug('Creating Status Bar', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('Creating Status Bar')
         self.statusbar = self.statusBar()
         self.curproj = self.addStatusbarButtons(
             'Project:', actions=[('None', File.openExistingProject)])
@@ -230,7 +222,8 @@ class Gui(QtWidgets.QMainWindow):
         self.canEdit = False
 
         ################# MENUBAR ###########################
-        pf.debug('Creating Menu Bar', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('Creating Menu Bar')
         self.menu = menu.MenuBar('TopMenu')
         for key in pf.cfg['gui/menu']:
             self.insertModuleMenu(key)
@@ -250,20 +243,26 @@ class Gui(QtWidgets.QMainWindow):
 
         # The central widget is where the rendering viewports will be
         # For now, use an empty widget
-        pf.debug('Creating Central Widget', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('Creating Central Widget')
         self.central = QtWidgets.QWidget()
         self.central.autoFillBackground()
         self.central.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding,
                                    QtWidgets.QSizePolicy.MinimumExpanding)
-        #self.central.resize(*size)
+        # self.central.resize(*size)
         if pf.options.canvas:
             self.viewports = viewport.MultiCanvas(parent=self.central)
             self.central.setLayout(self.viewports)
         self.splitter.addWidget(self.central)
 
         # Create the console
-        self.console = pyconsole.PyConsole(context=pf.interpreter, parent=self)
-        histfile = pf.cfg['gui/consolehistfile']
+        histfile = pf.cfg['console/histfile']
+        histmax = pf.cfg['console/histmax']
+        linenumbers = pf.cfg['console/linenumbers']
+        self.console = pyconsole.PyConsole(
+            context=pf.interpreter, parent=self,
+            historysize=histmax, linenumbers=linenumbers
+        )
         if histfile.exists():
             self.console.editline.loadhistory(histfile)
         self.splitter.addWidget(self.console)
@@ -272,14 +271,16 @@ class Gui(QtWidgets.QMainWindow):
         self.splitter.setSizes(splitsize)
 
         ################# TOOLBAR ###########################
-        pf.debug('Creating ToolBar', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('Creating ToolBar')
         self.toolbar = self.addToolBar('Top ToolBar')
 
         # Define Toolbar contents
         self.actions = toolbar.addActionButtons(self.toolbar)
         # timeout button
         toolbar.addTimeoutButton(self.toolbar)
-        pf.debug('Creating Toolbars', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('Creating Toolbars')
         self.camerabar = self.updateToolBar('camerabar', 'Camera ToolBar')
         self.modebar = self.updateToolBar('modebar', 'RenderMode ToolBar')
         self.viewbar = self.updateToolBar('viewbar', 'Views ToolBar')
@@ -347,15 +348,19 @@ class Gui(QtWidgets.QMainWindow):
         self.saved_views_name = utils.NameSequence('View')
 
         if self.viewsMenu:
-            name = next(self.saved_views_name)
+            # TODO: doesn't work !
+            # name =
+            next(self.saved_views_name)
             self.menu['Camera'].addAction('Save View', self.saveView)
 
         # Set specified geometry
-        pf.debug(f'Restore size {size}, pos {pos}', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print(f'Restore size {size}, pos {pos}')
         self.resize(*size)
         self.move(*pos)
 
-        pf.debug('Set Curdir', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('Set Curdir')
         self.setcurdir()
 
         # Drawing lock
@@ -371,7 +376,8 @@ class Gui(QtWidgets.QMainWindow):
 
         # Modeless child dialogs
         self.doc_dialog = None
-        pf.debug('Done initializing GUI', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('Done initializing GUI')
 
         # Set up signal/slot connections
         self.signals = signals.Signals()
@@ -380,10 +386,10 @@ class Gui(QtWidgets.QMainWindow):
         self.filewatch = FileWatcher()
 
         # Set up hot keys: hitting the key will emit the corresponding signal
-        self.hotkey  = {
+        self.hotkey = {
             QtCore.Qt.Key_F2: self.signals.SAVE,
             QtCore.Qt.Key_F11: self.signals.FULLSCREEN,
-            }
+        }
 
         # keep a list of the Dialog children
         self.dialogs = []
@@ -423,10 +429,11 @@ class Gui(QtWidgets.QMainWindow):
 
         If the module defines an attribute MenuData, it is
         inserted in the MenuBar. If it defines a function
-        menu_enabler, it is called afterwards.
+        menu_enabler, it is called afterward.
 
         """
-        pf.debug(f"Creating Top Menu item {name}", pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print(f"Creating Top Menu item {name}")
         modname = 'pyformex.gui.menus.'+name
         module = importlib.import_module(modname)
         self.menu.insertItems([module.MenuData])
@@ -451,9 +458,10 @@ class Gui(QtWidgets.QMainWindow):
 
     def saveConsoleHistory(self):
         """Save the console history"""
-        pf.debug("Save console history")
+        if pf.debugon(pf.DEBUG.GUI):
+            print("Save console history")
         self.console.editline.savehistory(
-            pf.cfg['gui/consolehistfile'], pf.cfg['gui/consolehistmax'])
+            pf.cfg['console/histfile'], pf.cfg['console/histmax'])
 
 
     def close_doc_dialog(self):
@@ -492,10 +500,7 @@ class Gui(QtWidgets.QMainWindow):
 
         self.viewbtns = menu.ActionList(
             viewnames, self.setView,
-            menu=self.viewsMenu,
-            toolbar=self.viewbar,
-            icons = viewicons
-            )
+            menu=self.viewsMenu, toolbar=self.viewbar, icons=viewicons)
         self.update()
 
 
@@ -602,7 +607,8 @@ class Gui(QtWidgets.QMainWindow):
 
 
     def toggleAppScript(self):
-        pf.debug("Toggle between app and script", pf.DEBUG.APPS)
+        if pf.debugon(pf.DEBUG.APPS):
+            print("Toggle between app and script")
         from pyformex import apps
         appname = pf.cfg['curfile']
         if utils.is_script(appname):
@@ -698,15 +704,16 @@ class Gui(QtWidgets.QMainWindow):
             # script file
             label = 'Script:'
             name = Path(appname).name
-            self.canPlay = self.canEdit = utils.is_pyFormex(appname)
+            self.canPlay = self.canEdit = utils.is_script(appname)
 
         pf.prefcfg['curfile'] = appname
-        #self.curfile.label.setText(label)
+        # self.curfile.label.setText(label)
         self.curfile.setText(label, 0)
         self.curfile.setText(name, 1)
         self.enableButtons(self.actions, ['Play', 'Info'], self.canPlay)
         self.enableButtons(self.actions, ['Edit'], self.canEdit)
-        self.enableButtons(self.actions, ['ReRun'], is_app and(self.canEdit or self.canPlay))
+        self.enableButtons(self.actions, ['ReRun'], is_app and (
+            self.canEdit or self.canPlay))
         self.enableButtons(self.actions, ['Step', 'Continue'], False)
         icon = 'ok' if self.canPlay else 'notok'
         iconpath = utils.findIcon(icon)
@@ -749,7 +756,8 @@ class Gui(QtWidgets.QMainWindow):
         Finally, the event is removed.
         """
         key = e.key()
-        pf.debug(f'Key {key} pressed', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print(f'Key {key} pressed')
         self.signals.WAKEUP.emit()
         signal = self.hotkey.get(key, None)
         if signal is not None:
@@ -784,7 +792,8 @@ class Gui(QtWidgets.QMainWindow):
 
         This includes the GUI size and position
         """
-        pf.debug('Store current settings', pf.DEBUG.CONFIG)
+        if pf.debugon(pf.DEBUG.CONFIG):
+            print('Store current settings')
         # store the history and main window size/pos
         pf.prefcfg['gui/scripthistory'] = self.scripthistory.files
         pf.prefcfg['gui/apphistory'] = self.apphistory.files
@@ -873,7 +882,8 @@ class Gui(QtWidgets.QMainWindow):
 
     def cleanup(self):
         """Cleanup the GUI (restore default state)."""
-        pf.debug('GUI cleanup', pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print('GUI cleanup')
         self.drawlock.release()
         pf.canvas.cancel_selection()
         pf.canvas.cancel_draw()
@@ -914,9 +924,11 @@ class Gui(QtWidgets.QMainWindow):
             script.force_finish()
         if exitDialog():
             self.drawlock.free()
-            pf.debug("Executing registered exit functions", pf.DEBUG.GUI)
+            if pf.debugon(pf.DEBUG.GUI):
+                print("Executing registered exit functions")
             for f in self.on_exit:
-                pf.debug(f, pf.DEBUG.GUI)
+                if pf.debugon(pf.DEBUG.GUI):
+                    print(f)
                 f()
             self.writeSettings()
             self.saveConsoleHistory()
@@ -939,8 +951,12 @@ class Gui(QtWidgets.QMainWindow):
         """Go into interactive mode until the user exits"""
         try:
             # Make the workdir the current dir
-            os.chdir(pf.cfg['workdir'])
-            pf.debug(f"Setting workdir to {pf.cfg['workdir']}", pf.DEBUG.INFO)
+            workdir = pf.options.workdir
+            if workdir is None:
+                workdir = pf.cfg['workdir']
+            os.chdir(workdir)
+            if pf.debugon(pf.DEBUG.INFO):
+                print(f"Setting workdir to {workdir}")
         except Exception:
             # Save the current dir as workdir
             Settings.updateSettings({'workdir': Path.cwd(), '_save_': True})
@@ -948,17 +964,21 @@ class Gui(QtWidgets.QMainWindow):
         self.setcurdir()
         pf.interactive = True
         if easter_egg:
-            pf.debug("Show easter egg", pf.DEBUG.INFO)
+            if pf.debugon(pf.DEBUG.INFO):
+                print("Show easter egg")
             try:
                 draw.playScript(easter_egg, encoding='egg')
             except Exception:
                 pass
 
-        pf.debug("Start main loop", pf.DEBUG.INFO)
+        if pf.debugon(pf.DEBUG.INFO):
+            print("Start main loop")
         now = datetime.datetime.now()
-        pf.verbose(3, f"GUI startup time = {now - pf.start_time}")
+        if pf.verbosity(3):
+            print(f"GUI startup time = {now - pf.start_time}")
         res = pf.app.exec_()
-        pf.debug(f"Exit main loop with value {res}", pf.DEBUG.INFO)
+        if pf.debugon(pf.DEBUG.INFO):
+            print(f"Exit main loop with value {res}")
         return res
 
 
@@ -1003,10 +1023,29 @@ class Gui(QtWidgets.QMainWindow):
             tb.setEnabled(enable)
 
 
+    def popupMessage(self, text, actions=['OK'], level='info', modal=True,
+                     align='00', **kargs):
+        """Show a short message widget and wait for user acknowledgement.
+
+        There are three levels of messages: 'info', 'warning' and 'error'.
+        They differ only in the icon that is shown next to the test.
+        By default, the message widget has a single button with the text 'OK'.
+        The dialog is closed if the user clicks a button.
+        The return value is the button text.
+        """
+        w = widgets.MessageBox(parent=self, text=text, level=level,
+                               actions=actions, modal=modal, **kargs)
+        # if align == '--':
+        #    w.move(100, 100)
+        if modal:
+            return w.getResults()
+
+
 def exitDialog():
     """Show the exit dialog to the user.
 
     """
+    from .draw import askItems, _I
     confirm = pf.cfg['gui/exitconfirm']
 
     if confirm == 'never':
@@ -1019,12 +1058,14 @@ def exitDialog():
     print(f"pyFormex globals: {list(pf.PF.keys())}")
 
     save_opts = ['To current project file', 'Under another name', 'Do not save']
-    res = draw.askItems(
-        [draw._I('info', itemtype='label', value="You have unsaved global variables. What shall I do?"),
-          draw._I('save', itemtype='vradio', choices=save_opts, text='Save the current globals'),
-          draw._I('reopen', pf.cfg['openlastproj'], text="Reopen the project on next startup"),
-          ],
-        caption='pyFormex exit dialog')
+    res = askItems(caption='pyFormex exit dialog', items=[
+        _I('info', itemtype='label',
+           value="You have unsaved global variables. What shall I do?"),
+        _I('save', itemtype='vradio', choices=save_opts,
+           text='Save the current globals'),
+        _I('reopen', pf.cfg['openlastproj'],
+           text="Reopen the project on next startup"),
+    ])
 
     if not res:
         # Cancel the exit
@@ -1207,9 +1248,8 @@ class Application(QtWidgets.QApplication):
     forbidden_styles = ['gtk2']   # causes segmentation fault
 
     def __init__(self, args=sys.argv[:1]):
-        if len(args) != 1:
-            pf.debug(f"Arguments passed to the QApplication: {args}",
-                     pf.DEBUG.INFO)
+        if pf.debugon(pf.DEBUG.INFO):
+            print(f"Arguments passed to the QApplication: {args}")
         # Make sure numbers are always treated correctly on in/out
         # The idiots that think otherwise, perhaps never use files
         # as interface between programs.
@@ -1218,15 +1258,16 @@ class Application(QtWidgets.QApplication):
         QtCore.QLocale.setDefault(locale)
         # Initialize the QApplication
         super().__init__(args)
-        pf.debug(f"Arguments left after starting QApplication: {args}",
-                 pf.DEBUG.INFO)
+        if pf.debugon(pf.DEBUG.INFO):
+            print(f"Arguments left after starting QApplication: {args}")
         # Set application attributes"
         self.setOrganizationName("pyformex.org")
         self.setOrganizationDomain("pyformex.org")
         self.setApplicationName("pyFormex")
         self.setApplicationVersion(pf.__version__)
         # Set appearance
-        pf.debug("Setting Appearance", pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print("Setting Appearance")
         self.setAppearance()
         # Quit application on aboutToQuit or lastWindowClosed signals
         self.aboutToQuit.connect(self.quit)
@@ -1307,23 +1348,25 @@ class Application(QtWidgets.QApplication):
 
 def showSplash():
     """Show the splash screen"""
-    pf.debug("Loading the splash image", pf.DEBUG.GUI)
+    if pf.debugon(pf.DEBUG.GUI):
+        print("Loading the splash image")
     splash = None
     splash_path = pf.cfg['gui/splash']
     if splash_path.exists():
-        pf.debug(f"Loading splash {splash_path}", pf.DEBUG.GUI)
+        if pf.debugon(pf.DEBUG.GUI):
+            print(f"Loading splash {splash_path}")
         splashimage = QPixmap(splash_path)
         splash = QtWidgets.QSplashScreen(splashimage)
         splash.setFont(QtGui.QFont("Helvetica", 20))
         splash.showMessage(pf.Version(),
-                           QtCore.Qt.AlignHCenter|QtCore.Qt.AlignTop,
+                           QtCore.Qt.AlignHCenter | QtCore.Qt.AlignTop,
                            QtCore.Qt.red)
         splash.show()
     return splash
 
 
 # TODO: some things could be moved in Application or Gui class
-def createGUI():
+def createGUI():    # noqa: C901
     """Create the Qt application and GUI.
 
     A (possibly empty) list of command line options should be provided.
@@ -1337,13 +1380,14 @@ def createGUI():
     dri = qtgl.hasDRI()
 
     # Check for existing pyFormex processes
-    pf.debug("Checking for running pyFormex", pf.DEBUG.INFO)
+    if pf.debugon(pf.DEBUG.INFO):
+        print("Checking for running pyFormex")
     if pf.X11:
         windowname, running = findOldProcesses()
     else:
         windowname, running = "UNKOWN", []
-    pf.debug(f"{windowname}, {running}", pf.DEBUG.INFO)
-
+    if pf.debugon(pf.DEBUG.INFO):
+        print(f"{windowname}, {running}")
 
     while len(running) > 0:
         if len(running) >= 16:
@@ -1408,9 +1452,10 @@ You should seriously consider to bail out now!!!
     splash = showSplash()
 
     # create GUI, show it, run it
-    pf.debug("Creating the GUI", pf.DEBUG.GUI)
+    if pf.debugon(pf.DEBUG.GUI):
+        print("Creating the GUI")
     if splash is not None:
-        splash.showMessage("Creating the GUI");
+        splash.showMessage("Creating the GUI")
     if pf.options.geometry:
         w, h, x, y = splitXgeometry(pf.options.geometry)
         size = (w, h)
@@ -1425,48 +1470,34 @@ You should seriously consider to bail out now!!!
     pf.GUI = Gui(windowname, size, pos, splitsize)
 
     # update interpreter locals
-    pf.interpreter.locals.update(draw.Globals())
+    pf.interpreter.locals.update(core.Globals())
 
     # setup the console
     pf.GUI.console.clear()
-    pf.GUI.console.writecolor(f"""\
-{pf.fullVersion()}   (C) Benedict Verhegghe
-
-pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it under the conditions of the GNU General Public License, version 3 or later. See Help->License or the file COPYING for details.
-""")
+    pf.GUI.console.writecolor(
+        f"{pf.fullVersion()}   (C) Benedict Verhegghe\n"
+        "pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, "
+        "and you are welcome to redistribute it under the conditions of the "
+        "GNU General Public License, version 3 or later. See Help->License "
+        "or the file COPYING for details.")
 
     # Set interaction functions
 
-    def show_warning(message, category, filename, lineno, file=None, line=None):
-        """Replace the default warnings.showwarning
-
-        We display the warnings using our interactive warning widget.
-        This feature can be turned off by setting
-        cfg['warnings/popup'] = False
-        """
-        message = str(message)
-        # NOTE: the following will expand our short message identifier
-        # with the expanded message text from messages.py
-        full_message = warnings.formatwarning(message, category, filename, lineno, line)
-        print(full_message)
-        res, check = draw.showMessage(
-            full_message, level='warning',
-            check="Do not show this warning anymore in this and future sessions")
-        utils.filterWarning(message, category=category, save=check[0])
-
     if pf.cfg['warnings/popup']:
-        warnings.showwarning = show_warning
+        utils.set_warnings(nice=True, popup=True)
+        pf.GUI.onExit(utils.reset_warnings)
 
-
-    pf.warning = draw.showWarning
-    pf.error = draw.showError
+    pf.print = draw.printc
+    pf.warning = utils.warning
+    pf.error = utils.error
 
 
     # setup the canvas
     if pf.options.canvas:
         if splash is not None:
-            splash.showMessage("Creating the canvas");
-        pf.debug("Setting the canvas", pf.DEBUG.GUI)
+            splash.showMessage("Creating the canvas")
+        if pf.debugon(pf.DEBUG.GUI):
+            print("Setting the canvas")
         pf.app.processEvents()
         pf.GUI.viewports.changeLayout(1)
         pf.GUI.viewports.setCurrent(0)
@@ -1483,11 +1514,13 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
 
 
     # setup the status bar
-    pf.debug("Setup status bar", pf.DEBUG.GUI)
+    if pf.debugon(pf.DEBUG.GUI):
+        print("Setup status bar")
     if pf.options.canvas:
         pf.GUI.addCoordsTracker()
         pf.GUI.toggleCoordsTracker(pf.cfg['gui/coordsbox'])
-    pf.debug(f"Using window name {pf.GUI.windowTitle()}", pf.DEBUG.GUI)
+    if pf.debugon(pf.DEBUG.GUI):
+        print(f"Using window name {pf.GUI.windowTitle()}")
 
     # Script/App menu
     if splash is not None:
@@ -1504,12 +1537,12 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
 
     # Load configured plugin menus
     if splash is not None:
-        splash.showMessage("Loading plugins");
+        splash.showMessage("Loading plugins")
     plugins.loadConfiguredPlugins()
 
     # show current application/file
     if splash is not None:
-        splash.showMessage("Load current application");
+        splash.showMessage("Load current application")
     appname = pf.cfg['curfile']
     pf.GUI.setcurfile(appname)
 
@@ -1517,29 +1550,31 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
 
     # cleanup
     if splash is not None:
-        splash.showMessage("Set status bar");
-    #pf.GUI.addStatusBarButtons()
+        splash.showMessage("Set status bar")
+    # pf.GUI.addStatusBarButtons()
 
-    pf.debug("Showing the GUI", pf.DEBUG.GUI)
+    if pf.debugon(pf.DEBUG.GUI):
+        print("Showing the GUI")
     if splash is not None:
-        splash.showMessage("Show the GUI");
+        splash.showMessage("Show the GUI")
 
     pf.GUI.show()
 
-    if pf.DEBUG.GUI in pf.options.debuglevel:
-        pf.debug(', '.join(
+    if pf.debugon(pf.DEBUG.GUI):
+        print(', '.join(
             (qtutils.sizeReport(pf.GUI, 'main:'),
              qtutils.sizeReport(pf.GUI.box, 'box:'),
              qtutils.sizeReport(pf.GUI.central, 'central:'),
              qtutils.sizeReport(pf.GUI.console, 'console'),
              )
-        ), pf.DEBUG.GUI)
+        ))
 
     if splash is not None:
         # remove the splash window
         splash.finish(pf.GUI)
 
-    pf.debug("Update", pf.DEBUG.GUI)
+    if pf.debugon(pf.DEBUG.GUI):
+        print("Update")
     pf.GUI.update()
 
     if pf.cfg['gui/fortune']:
@@ -1549,23 +1584,24 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
 
     # display startup warning
     if pf.cfg['gui/startup_warning']:
-        utils.warn(pf.cfg['gui/startup_warning'])
+        pf.warning(pf.cfg['gui/startup_warning'])
 
     # Enable the toolbars
     pf.GUI.enableToolbars()
 
-    #pf.app.setQuitOnLastWindowClosed(False)
-    pf.debug("ProcessEvents", pf.DEBUG.GUI)
+    # pf.app.setQuitOnLastWindowClosed(False)
+    if pf.debugon(pf.DEBUG.GUI):
+        print("ProcessEvents")
     pf.app_started = True
     pf.app.processEvents()
 
     ##### GUI ready ########
     if pf.options.runall:
-       from pyformex.appsdir.RunAll import runAll
-       runAll(count=pf.options.runall, shuffle=True)
-       # TODO: should we continue or exit here?
-       pf.GUI.close()
-       pf.app.quit()
+        from pyformex.appsdir.RunAll import runAll
+        runAll(count=pf.options.runall, shuffle=True)
+        # TODO: should we continue or exit here?
+        pf.GUI.close()
+        pf.app.quit()
 
     # load last project
     #  TODO
@@ -1576,7 +1612,8 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
             if proj:
                 File.setProject(proj)
     #
-    pf.debug("GUI Started", pf.DEBUG.GUI)
+    if pf.debugon(pf.DEBUG.GUI):
+        print("GUI Started")
     return 0
 
 
@@ -1584,9 +1621,9 @@ def createDatabases():
     """Create unified database objects for all menus."""
     from pyformex.plugins import objects
     from pyformex.geometry import Geometry
-    from pyformex.formex import Formex
-    from pyformex.mesh import Mesh
-    from pyformex.trisurface import TriSurface
+    # from pyformex.formex import Formex
+    # from pyformex.mesh import Mesh
+    # from pyformex.trisurface import TriSurface
     from pyformex.curve import PolyLine, BezierSpline
     from pyformex.plugins.nurbs import NurbsCurve
     pf.GUI.database = objects.Objects()
@@ -1599,7 +1636,7 @@ def createDatabases():
         'polyline': objects.DrawableObjects(clas=PolyLine),
         'nurbs': objects.DrawableObjects(clas=NurbsCurve),
         'curve': objects.DrawableObjects(clas=BezierSpline),
-        }
+    }
     pf.GS = pf.GUI.selection['geometry']
 
 
