@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -37,11 +37,11 @@ from pyformex.formex import Formex
 from pyformex import colors
 from .drawable import Actor
 from .textext import FontTexture
-from .sanitize import saneLineWidth
+from .sanitize import saneFloat
 
 
-__all__ = ['BboxActor', 'Rectangle', 'Line', 'Lines', 'Grid2D', 'ColorLegend',
-            'Grid']
+__all__ = ('BboxActor', 'Rectangle', 'Line', 'Lines', 'Grid2D', 'ColorLegend',
+           'Grid')
 
 ### Decorations ###############################################
 
@@ -179,7 +179,9 @@ class ColorLegend(Actor):
     The `ColorScale` example script provides opportunity to experiment with
     different settings.
     """
-    def __init__(self, colorscale, ncolors, x, y, w, h, ngrid=0, linewidth=None, nlabel=-1, size=18, font=None, textcolor=None, dec=2, scale=0, lefttext=False, **kargs):
+    def __init__(self, colorscale, ncolors, x, y, w, h, ngrid=0, linewidth=None,
+                 nlabel=-1, size=18, font=None, textcolor=None, dec=2, scale=0,
+                 lefttext=False, **kargs):
         """Initialize the ColorLegend."""
         from pyformex.gui import colorscale as cs
         self.cl = cs.ColorLegend(colorscale, ncolors)
@@ -192,7 +194,7 @@ class ColorLegend(Actor):
             self.ngrid = ncolors
             if self.ngrid > 50:
                 self.ngrid = 0
-        self.linewidth = saneLineWidth(linewidth)
+        self.linewidth = saneFloat(linewidth)
         self.nlabel = int(nlabel)
         if self.nlabel < 0:
             if self.ngrid > 0:
@@ -206,15 +208,18 @@ class ColorLegend(Actor):
         self.ygap = 4  # (min) vert. gap between labels
 
         F = simple.rectangle(1, ncolors, self.w, self.h).trl([self.x, self.y, 0.])
-        Actor.__init__(self, F, rendertype=2, lighting=False, color=self.cl.colors, **kargs)
+        Actor.__init__(self, F, rendertype=2, lighting=False,
+                       color=self.cl.colors, **kargs)
 
         if self.ngrid > 0:
-            F = simple.rectangle(1, self.ngrid, self.w, self.h).trl([self.x, self.y, 0.])
-            G = Actor(F, rendertype=2, lighting=False, color=colors.black, linewidth=self.linewidth, mode='wireframe')
+            F = simple.rectangle(1, self.ngrid, self.w, self.h).trl(
+                [self.x, self.y, 0.])
+            G = Actor(F, rendertype=2, lighting=False, color=colors.black,
+                      linewidth=self.linewidth, mode='wireframe')
             self.children.append(G)
 
         # labels
-        # print("LABELS: %s" % self.nlabel)
+        # print(f"LABELS: {self.nlabel}")
         if self.nlabel > 0:
             from .import textext
 
@@ -224,10 +229,11 @@ class ColorLegend(Actor):
                 font = FontTexture(font, size)
             self.font = font
             fh = self.font.height
-            pf.debug("FONT HEIGHT %s" % fh, pf.DEBUG.DRAW)
+            if pf.debugon(pf.DEBUG.DRAW):
+                print(f"FONT HEIGHT {fh}")
 
             if textcolor is None:
-                textcolor = pf.canvas.settings['fgcolor']
+                textcolor = pf.canvas.settings.fgcolor
 
             if self.lefttext:
                 x = F.coords[0, 0, 0] - self.xgap
@@ -247,15 +253,14 @@ class ColorLegend(Actor):
                 da = self.h / self.nlabel
 
             vals = cs.ColorLegend(colorscale, self.nlabel).limits
-            #print("VALS",vals)
 
             ypos = self.y + da * np.arange(self.nlabel+1)
 
             yok = self.y - 0.01*dh
             for (y, v) in zip(ypos, vals):
-                #print(y,v,yok)
                 if y >= yok:
-                    t = textext.Text(("%%.%df" % self.dec) % (v*self.scale), (x, y), size=size, gravity=gravity, color=textcolor)
+                    t = textext.Text(("%%.%df" % self.dec) % (v*self.scale), (x, y),
+                                     size=size, gravity=gravity, color=textcolor)
                     self.children.append(t)
                     yok = y + dh
 
