@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -92,6 +92,8 @@ class PluginMenu():
 
     def load(self):
         """Load the plugin menu"""
+        if pf.debugon(pf.DEBUG.PLUGIN):
+            print("  Loading plugin menu:", self.fullname)
         importlib.import_module(self.fullname)
         module = self.module = sys.modules.get(self.fullname, None)
         if isinstance(module, ModuleType) and hasattr(module, 'create_menu'):
@@ -113,10 +115,12 @@ class PluginMenu():
             self.menu.insertItems([
                 ("Reload Menu", self.reload),
                 ("Close Menu", self.close),
-                ])
+            ])
 
     def close(self):
         """Close the menu."""
+        if pf.debugon(pf.DEBUG.PLUGIN):
+            print("  Closing plugin menu:", self.name)
         pf.GUI.menu.removeItem(self.name)
 
     def reload(self):
@@ -127,7 +131,7 @@ class PluginMenu():
         self.refresh()
         try:
             self.module.on_reload()
-        except:
+        except Exception:
             pass
         self.show(before=before)
 
@@ -150,6 +154,7 @@ class PluginMenu():
     def get(clas, name):
         return clas._register_.get(name, None)
 
+
 # Register the pyFormex plugin menus
 PluginMenu('Geometry')
 PluginMenu('Mesh')
@@ -171,14 +176,14 @@ def loadConfiguredPlugins(ok_plugins=None):
     """
     if ok_plugins is None:
         ok_plugins = pf.cfg['gui/pluginmenus']
-        pf.debug("Configured plugins: %s" % ok_plugins, pf.DEBUG.PLUGIN)
+        if pf.debugon(pf.DEBUG.PLUGIN):
+            print("Configured plugins:", ok_plugins)
     for p in PluginMenu._register_.values():
-        pf.debug(f"Plugin menu: {p.name}", pf.DEBUG.PLUGIN)
+        if pf.debugon(pf.DEBUG.PLUGIN):
+            print("Plugin menu:", p.name)
         if p.name in ok_plugins:
-            pf.debug("  Loading plugin menu: %s" % p, pf.DEBUG.PLUGIN)
             p.load()
         else:
-            pf.debug("  Closing plugin menu: %s" % p, pf.DEBUG.PLUGIN)
             p.close()
 
 
