@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -174,7 +174,7 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
     flip: bool
         If True, the image scanlines are flipped upside down.
         This is practical because image files are usually stored in top down
-        order, while OpenGL uses an upwards positive direction, requiring a
+        order, while OpenGL uses an upward positive direction, requiring a
         flip to show the image upright.
     indexed: bool or None.
         If True, the result will be an indexed image where each pixel color
@@ -231,7 +231,8 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
     """
     image = resizeImage(image, *resize)
 
-    pf.debug("IMAGE FORMAT %s" % image.format(), pf.DEBUG.IMAGE)
+    if pf.debugon(pf.DEBUG.IMAGE):
+        print("IMAGE FORMAT", image.format())
 
     if indexed:
         image = image.convertToFormat(QImage.Format_Indexed8)
@@ -310,7 +311,7 @@ def numpy2qimage(array, flip=False):
     flip: bool
         If True, the image scanlines are flipped upside down.
         This is practical because image files are usually stored in top down
-        order, while OpenGL uses an upwards positive direction, requiring a
+        order, while OpenGL uses an upward positive direction, requiring a
         flip to show the image upright.
 
     Notes
@@ -418,7 +419,7 @@ def qimage2glcolor(image, resize=(0, 0), order='RGB'):
         Array of float values in the range 0.0 to 1.0,
         containing the OpenGL colors corresponding to the image RGB colors.
         By default the image is flipped upside-down because the vertical
-        OpenGL axis points upwards, while bitmap images are stored downwards.
+        OpenGL axis points upward, while bitmap images are stored downward.
     """
     c = qimage2numpy(image, resize=resize, order=order, flip=True, indexed=False)
     c = c.reshape(-1, len(order))
@@ -458,7 +459,7 @@ def saveGreyImage(a, f, flip=True):
     flip: bool
         If True (default), the vertical axis is flipped, so that images are
         stored starting at the top. If your data already have the vertical axis
-        downwards, use flip=False.
+        downward, use flip=False.
 
     Note
     ----
