@@ -1,9 +1,9 @@
 #
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -27,7 +27,6 @@
 """Partitioning tools
 
 """
-
 import numpy as np
 
 import pyformex as pf
@@ -68,7 +67,7 @@ def testview(F, V, P):
     print(V.center())
     print(F.center())
     ps.undraw(VA)
-    VA = draw(V)
+    VA = ps.draw(V)
     area, norm = geomtools.areaNormals(V.coords)
     N = np.norm[0]
     return P, N
@@ -102,6 +101,7 @@ def splitProp(G, name):
     if split:
         names = ['%s-%s' % (name, i) for i in np.unique(G.prop)]
         ps.export2(names, split)
+        return dict(zip(names, split))
 
 
 waiting = True
@@ -130,7 +130,7 @@ def partition(Fin, prop=0):
     global FA, VA, waiting
 
     # start color
-    keepprops = prop
+    # keepprops = prop
     if prop is None or prop < 0:
         prop = 0
 
@@ -139,7 +139,7 @@ def partition(Fin, prop=0):
     F = Fin.translate(initial_trl)
 
     # Store the initial properties and make all properties equal to start value
-    initial_prop = F.prop
+    # initial_prop = F.prop
     F.setProp(prop)
 
     # draw it
@@ -149,11 +149,10 @@ def partition(Fin, prop=0):
     FA = ps.draw(F, view='front')
 
     # create a centered cross plane, large enough
-    bb = F.bbox()
+    # bb = F.bbox()
     siz = F.sizes().max()
     V = ps.Formex([[[0., 0., 0.], [1., 0., 0.], [1., 1., 0.]],
-                [[1., 1., 0.], [0., 1., 0.], [0., 0., 0.]]],
-               0)
+                   [[1., 1., 0.], [0., 1., 0.], [0., 0., 0.]]], 0)
     V = V.translate(-V.center()).rotate(90, 1).scale(siz)
 
     cut_planes = []
@@ -176,7 +175,7 @@ def partition(Fin, prop=0):
             print("Plane: point %s, normal %s" % (P, N))
         elif res == "Keep Cut":
             ps.undraw(FA)
-            #undraw(VA)
+            # ps.undraw(VA)
             cut_planes.append((P, N))
             prop += 1
             F = colorCut(F, -P, N, prop)
@@ -195,19 +194,18 @@ def partition(Fin, prop=0):
 
 def savePartitions(F):
     print("Current dir is %s" % Path.cwd())
-    if ack("Save the partitioned Formex?"):
-        writeFormex(F, 'part.fmx')
+    if ps.ack("Save the partitioned Formex?"):
+        ps.writeGeometry('partition.pzf', {'partition': F})
         ps.clear()
 
-    if ack("Reread/draw the partitioned Formex?"):
-        F = readFormex('part.fmx')
+    if ps.ack("Reread/draw the partitioned Formex?"):
+        F = ps.readGeometry('partition.pzf')['partition']
         ps.draw(F)
 
-    splitProp(F, 'part')
+    d = splitProp(F, 'part')
 
-    if ack("Save the partitions separately?"):
-        for (k, v) in d.items():
-            writeFormex(v, "%s.fmx"%k)
+    if ps.ack("Save the partitions separately?"):
+        ps.writeGeometry('partitions.pzf', d)
 
 
 # End
