@@ -1,9 +1,9 @@
 #   Copyright 2014-2020 Darsh Ranjan
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -1025,8 +1025,8 @@ def _can_mmap(stream):
             _np.memmap(stream, 'u1', 'c')
             stream.seek(pos)
             return True
-        except Exception as e:
+        except Exception:
             stream.seek(pos)
             return False
-    except Exception as e:
+    except Exception:
         return False
