@@ -1,9 +1,9 @@
 # flake8: noqa
 ##
-##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
+##  SPDX-FileCopyrightText: © 2007-2024 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
+##  This file is part of pyFormex 3.5  (Thu Feb  8 19:11:13 CET 2024)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -103,7 +103,7 @@ def createPointsOnSurface():
 def showBorder():
     S = selection.check(single=True)
     if S:
-        border = S.border()
+        border = S.borderMeshes()
         if border:
             print("The border consists of %s parts" % len(border))
             print("The sorted border edges are: ")
@@ -162,17 +162,17 @@ def deleteTriangles():
     S = selection.check(single=True)
     if S:
         picked = pick('element')
-        #print picked
+        # print picked
         if picked:
             picked = picked[0]
-            #print picked
+            # print picked
             if len(picked) > 0:
-                #print S.nelems()
+                # print S.nelems()
                 S = S.cclip(picked)
-                #print "DELETE",type(S)
+                # print "DELETE",type(S)
                 name = selection.names[0]
-                #print name
-                #print S.nelems()
+                # print name
+                # print S.nelems()
                 export({name: S})
                 selection.draw()
 
@@ -383,7 +383,7 @@ def partitionByAngle():
         pf.app.processEvents()
         if res:
             selection.remember()
-            with Timer() as t:
+            with Timing() as t:
                 p = S.partitionByAngle(angle=res['angle'], sort=res['sort by'])
                 S = S.setProp(p + res['firstprop'])
             nprops = len(S.propSet())
@@ -602,7 +602,7 @@ def slicer():
         axis = res['Direction']
         nslices = res['# slices']
         with busyCursor():
-            with Timer("Sliced", auto=True):
+            with Timing("Sliced", auto=True):
                 slices = S.slice(dir=axis, nplanes=nslices)
         print([s.nelems() for s in slices])
         draw([s for s in slices if s.nelems() > 0], color='red',
@@ -633,7 +633,7 @@ def spliner():
         hasnan = [isnan(s.coords).any() for s in split]
         print(hasnan)
         print(sum(hasnan))
-        #print [s.closed for s in split]
+        # print [s.closed for s in split]
         export({'%s/split' % selection[0]: split})
         draw(split, color='blue', bbox='last', view=None)
         splines = [BezierSpline(s.coords[s.elems[:, 0]], closed=True) for s in split]
@@ -686,7 +686,7 @@ def surface2abq():
     S = selection.check(single=True)
     if S:
         types = ["Abaqus INP files (*.inp)"]
-        fn = askNewFilename(pf.cfg['workdir'], types)
+        fn = askFilename(pf.cfg['workdir'], types)
         if fn:
             print("Exporting surface model to %s" % fn)
             updateGUI()
@@ -697,7 +697,7 @@ def volume2abq():
     if PF['volume'] is None:
         return
     types = ["Abaqus INP files (*.inp)"]
-    fn = askNewFilename(pf.cfg['workdir'], types)
+    fn = askFilename(pf.cfg['workdir'], types)
     if fn:
         print("Exporting volume model to %s" % fn)
         updateGUI()
@@ -1012,23 +1012,27 @@ def remesh():
     #   4      4       quality quad4
 
     if res:
-        pf.verbose(2, f"Remeshing {name}")
+        if pf.verbosity(2):
+            print(f"Remeshing {name}")
         qname = res['name']
         res.pop('name', None)
         for k in ['scale', 'faces', 'vertices']:
             if k != res['resolution']:
                 res.pop(k, None)
         res.pop('resolution', None)
-        with Timer('Remeshing') as t:
+        with Timing('Remeshing') as t:
             mesh = S.remesh(**res)
         if mesh:
-            pf.verbose(2, f"Converted {name} to {mesh.elName()} Mesh named {qname} in {t.mem:.6f} sec.")
-            pf.verbose(2, mesh)
+            if pf.verbosity(2):
+                print(f"Converted {name} to {mesh.elName()} Mesh"
+                      f"named {qname} in {t.mem:.6f} sec.")
+                print(mesh)
             export({qname:mesh})
             pf.GUI.selection['geometry'].set([qname])
             pf.GUI.selection['geometry'].draw()
         else:
-            pf.verbose(2, "Conversion failed")
+            if pf.verbosity(2):
+                print("Conversion failed")
 
 
 def tri2quad_auto(suffix='_quad4'):
